# Yuhi (यूँ ही)

|                |                                                              |
|----------------|--------------------------------------------------------------|
| Compatibility  | ![Py-Version]                                                |
| Quality Checks | [![lint check][precommit-badge]]() [![tests][tests-badge]]() |
| Package        | ![pypi-v] ![pypi-downloads]                                  |
| MetaData       | [![license-badge]][license]                                  |                                                                                                                                                                                           

A CLI tool to create project structue based on standard and custom templates.
> Yuhi /y-oo-n-h-ee/ is a Hindi word meaning "casually" or "at random"

---
Made with :heart:

[precommit-badge]: https://github.com/rsb-23/yuhi/actions/workflows/pre-commit.yml/badge.svg
[tests-badge]: https://github.com/rsb-23/yuhi/actions/workflows/test.yml/badge.svg
[license]: https://github.com/rsb-23/yuhi/blob/main/LICENSE
[license-badge]: https://img.shields.io/badge/License-MIT-blue.svg
[pypi-downloads]: https://img.shields.io/pypi/dm/yuhi?label=Downloads
[pypi-v]: https://img.shields.io/pypi/v/yuhi?label=latest
[py-version]: https://img.shields.io/pypi/pyversions/yuhi
